==> stellarium-25.3-2-x86_64.pkg.tar.zst: usr/share/stellarium/skycultures/inuit/description.md <==
# Inuit

## Introduction

The Inuit sky culture files available for Stellarium are an adaptation of John MacDonald's research in his book [#1]. While placements and specifics of Inuit constellations might differ from tribe to tribe, the information in Stellarium presents the constellations and general themes of the arctic universe.

## Description

## Constellations

##### Two Sunbeams

Aagjuuk, an important constellation for timekeeping.

##### Two Placed Far Apart

Akkuttujuuk, two stars signaling the return of sunlight to the arctic.

##### Dogs

Qimmiitt, five dogs harassing Nanook, or Nanurjuk, the polar bear.

##### Collarbones

Quturjuuk

##### Lamp Stand

Pituaq, stand containing the burning fuel providing light

##### Caribou

The big dipper is Tukturjuit, the caribou.

##### Two in Front

Sivulliik, "the first ones" , Little Orphan Boy being chased by an angry grandfather.

##### The One Behind

Kingulliq, the grandmother chasing the Two in Front

##### Breastbone

Sakiattiak, The Pleiades, are seen as a breast bone.

##### Runners

Orion's Belt is Ullaktut, three hunters lost on a hunting trip for Nanuk, the polar bear.

##### Blubber Container

Uqsuutaattiaq, a seal flipper skin sewn shut, contains fuel for lamps.

##### Never Moves

Nuuttuittuq is the North Star Polaris, the star that never moves.

##### Nephews or Nieces

The Orion Nebula, Qangimmaariik, a group of children.

##### The Milky Way

The Divider, Aviguti.

##### Name of a Murdered Man

Or sometimes: "He who never goes out on newly formed ice". Sikuliaqsiujuittuq is Procyon, the main star in Canis Minor.

## References

 - [#1]: John MacDonald. The Arctic Sky: Inuit Astronomy, Star Lore and Legend.
 - [#2]: [Wikipedia article on Inuit astronomy](http://en.wikipedia.org/wiki/Inuit_astronomy)

## Authors

This sky culture was contributed by *Karrie Berglund* of Digitalis Education Solutions, Inc. based primarily on the book [#1].

Illustrations are done by Johan Meuris.

## License

Text and data: GNU GPL v2.0

Illustrations: Free Art License

==> stellarium-25.4-1-x86_64.pkg.tar.zst: usr/share/stellarium/skycultures/inuit/description.md <==
# Inuit

## Introduction

Inuit are the native population of the Arctic. 

## Description

The Inuit sky culture files available for Stellarium are an adaptation of John MacDonald's research in his book [#1]. While placements and specifics of Inuit constellations might differ from tribe to tribe, the information in Stellarium presents the constellations and general themes of the arctic universe.

### The Milky Way

The Divider, Aviguti.


## Constellations

##### Two Sunbeams

Aagjuuk, an important constellation for timekeeping.

##### Two Placed Far Apart

Akkuttujuuk, two stars signaling the return of sunlight to the arctic.

##### Dogs

Qimmiitt, five dogs harassing Nanook, or Nanurjuk, the polar bear.

##### Collarbones

Quturjuuk

##### Lamp Stand

Pituaq, stand containing the burning fuel providing light

##### Caribou

The big dipper is Tukturjuit, the caribou.

##### Two in Front

Sivulliik, "the first ones" , Little Orphan Boy being chased by an angry grandfather.

##### The Old Woman Behind

Kingulliq, the grandmother chasing the Two in Front

##### Breastbone

Sakiattiak, The Pleiades, are seen as a breast bone.

##### Runners

Orion's Belt is Ullaktut, three hunters lost on a hunting trip for Nanuk, the polar bear.

##### Blubber Container

Uqsuutaattiaq, a seal flipper skin sewn shut, contains fuel for lamps.

##### Never Moves

Nuuttuittuq is the North Star Polaris, the star that never moves.

##### Nephews or Nieces

The Orion Nebula, Qangimmaariik, a group of children.

##### Name of a Murdered Man

Or sometimes: "He who never goes out on newly formed ice". Sikuliaqsiujuittuq is Procyon, the main star in Canis Minor.

## References

 - [#1]: John MacDonald. The Arctic Sky: Inuit Astronomy, Star Lore and Legend.
 - [#2]: [Wikipedia article on Inuit astronomy](http://en.wikipedia.org/wiki/Inuit_astronomy)

## Authors

This sky culture was contributed by *Karrie Berglund* of Digitalis Education Solutions, Inc. based primarily on the book [#1].

Illustrations are done by Johan Meuris.

## License

Text and data: GNU GPL v2.0

Illustrations: Free Art License
